import {PageContainer, PageContainerProps, View} from "@tarojs/components";
import {CSSProperties, FC, useEffect, useState} from "react";
import styles from './custom-page-container.module.scss'

const PageContainerInner: FC<PageContainerProps> = (props) => {
  const [visible, setVisible] = useState(props.show)

  useEffect(() => {
    if (props.show != visible) {
      setVisible(props.show);

      // todo 目前仅仅支持 after
      if (!props.show) {
        (props.onBeforeLeave as Function)?.();
        (props.onAfterLeave as Function)?.();
      }
    }
  }, [props.show])

  if (!props.show) {
    return null
  }

  const contentStyle = (): CSSProperties => {
    let style: CSSProperties = {}

    switch (props.position) {
      case "top":
        style.borderRadius = '0 0 10px 10px'
        style.top = 0
        break
      case 'bottom':
        style.borderRadius = '10px 10px 0 0'
        style.bottom = 0
        break
      case 'center':
        style.width = '90%'
        style.borderRadius = '10px'
        style.padding = '0'
        break
    }

    return style
  }

  return (
    <View className={styles.customPageContainer}>
      <View className={styles.overlay} onClick={props.onClickOverlay}></View>
      <View className={styles.content} style={contentStyle()}>{props.children}</View>
    </View>
  )
}

const CustomPageContainer: FC<PageContainerProps> = (props) => {
  if (process.env.TARO_ENV !== 'h5') {
    return (<PageContainer {...props} />)
  }
  return (<PageContainerInner {...props} />);
}

export default CustomPageContainer
