import {FC, useState} from "react";
import Tabs, {OnChangOpt} from "@/components/tabs/tabs";
import {Image, View} from "@tarojs/components";
import {CourseDepData} from "@/api";
import Collapse from "@/components/collapse/collapse";
import Hours from "@/pages/business/videoInfo/components/hours";
import Taro from "@tarojs/taro";
import CustomPageContainer from "@/components/custom-page-container/custom-page-container";
import MyButton from "@/components/button/MyButton";
import curRecord from '@/static/img/curRecord.png'
import hourRecord from '@/static/img/hourRecord.png'

interface Props {
  data: CourseDepData | null
  setHors: (is_complete: boolean, id: number) => void
  id: number
}

const tabList = [
  {title: '介绍', value: 0},
  {title: '目录', value: 1},
  // {title: '评价', value: 2},
]


const Catalogue: FC<Props> = ({data, setHors, id}) => {
  const [current, setCurrent] = useState(1)
  const [show, setShow] = useState(false)

  function jumCurHistory() {
    Taro.preload({course_id: id, name: data?.course.title})
    Taro.navigateTo({url: `/pages/business/curHistory/curHistory`})
  }

  function tabChange({tab}: OnChangOpt) {
    setCurrent(tab?.value as number)
  }

  function getHors(chapter_id?: number): Hour[] | null {
    for (const d of Object.values(data?.hours || {})) {
      if (d[0].chapter_id === chapter_id) {
        return d
      }
    }
    return null
  }

  function chapters_complete(chapter: Chapters): boolean {
    const hors = getHors(chapter.id)
    if (hors) {
      for (const hor of hors) {
        const courseHourRecordsFinish = data?.learn_hour_records?.find(d => d.id === hor.id)?.courseHourRecordsFinish
        if (courseHourRecordsFinish === 0 || !courseHourRecordsFinish) {
          return false
        }
      }
      return true
    }
    return false
  }

  function upChaptersOver(is_complete: boolean, id: number, index: number) {
    if (!index) {
      setHors(is_complete, id)
    } else {
      const ok = chapters_complete((Object.values(data?.chapters || {})?.[index - 1]))
      if (!ok) {
        Taro.showModal({title: '上一章节未完成'})
        return
      }
      setHors(is_complete, id)
    }
  }

  function learning() {
    const flats: Hour[] = Object.values(data?.hours || {}).flat(Infinity) as Hour[]
    if (data?.learn_record?.finished_count === data?.learn_record?.hour_count && flats.length) {
      setHors(true, flats[0].id)
      return
    }

    if (data?.learn_hour_records.length) {
      const lastTimeId = data.learn_hour_records[data.learn_hour_records.length - 1].id
      for (const [index, flat] of flats.entries()) {
        if (flat.id === lastTimeId) {
          const next = flats[index + 1]
          if (next) {
            setHors(true, next.id)
          }
        }
      }
    } else {
      Taro.showToast({title: "无播放视频", icon: 'error'})
    }
  }

  return (
    <>
      <View className='catalogue'>
        <Tabs tabList={tabList} onChange={tabChange} current={current}/>
        <View className='py-2 hours'>
          {current === 0 && <View className='short_desc'>{data?.course.short_desc || '无'}</View>}
          {current === 1 && <View>
            <View className='font-weight'>课程目录</View>
            {data?.chapters.length ? Object.values(data?.chapters || {}).map((d, index) => <View>
                <Collapse title={`${index + 1}.${d.name}`}>
                  <Hours
                    click={(is_complete, id) => upChaptersOver(is_complete, id, index)}
                    learn_hour_records={data.learn_hour_records}
                    data={getHors(d.id)}
                  />
                </Collapse>
              </View>)
              : <Hours data={data?.hours?.[0]} click={setHors} learn_hour_records={data?.learn_hour_records}/>}
          </View>}
          {current === 2 && <View className='text-center'>评论暂未开放</View>}
        </View>
      </View>

      <View className='Videobutton'>
        <MyButton onClick={learning}>立即学习</MyButton>
        <View className='px-3' onClick={() => setShow(true)}>...</View>
      </View>

      <CustomPageContainer
        show={show}
        position='bottom'
        onClickOverlay={() => setShow(false)}>
        <View className='more'>
          <View>更多操作</View>

          <View className='flex justify-around'>
            <View onClick={() => Taro.navigateTo({url: '/pages/business/history/history'})}>
              <Image src={curRecord} className='image'/>
              课程记录
            </View>
            <View onClick={jumCurHistory}>
              <Image src={hourRecord} className='image'/>
              当前课时学习记录
            </View>
          </View>

          <MyButton onClick={() => setShow(false)} type='default' fillet>取消</MyButton>
        </View>
      </CustomPageContainer>
    </>
  );
}

export default Catalogue
